*                                                                              .
*                 SAS Program to Score the TIMSS Advanced 1995                 .
*                          Advanced Mathematics Items                          .
*                        TIMSS Advanced 2008 User Guide                        .
*                                                                              .

SET MPRINT=ON.

DEFINE SCOREIT (TYPE  = !CHAREND('/') /
                ITEM  = !CHAREND('/') /
                RIGHT = !CHAREND('/') /
                NR    = !CHAREND('/') /
                NA    = !CHAREND('/') /
                OM    = !CHAREND('/') /
                OTHER = !CHAREND('/') ) .

* Code for multiple-choice items .

 !IF (!UPCASE(!TYPE)=MC) !THEN
    !DO !I !IN (!ITEM) .
       RECODE !I (!RIGHT = 1      )
                 (!NR    = 0      ) /* Not Reached      */
                 (!NA    = SYSMIS ) /* Not Administered */
                 (!OM    = 0      ) /* Omitted          */
                 (!OTHER = 0      ) /* Other Missing    */
                 (ELSE   = 0      ) .
    !DOEND .
 !IFEND .

 * Code for constructed-response items .

 !IF (!UPCASE(!TYPE)=CR) !THEN
    !DO !I !IN (!ITEM).
       RECODE !I (10 THRU 19 = 1      )
                 (20 THRU 29 = 2      )
                 (30 THRU 39 = 3      )
                 (70 THRU 79 = 0      )
                 (!NR        = 0      ) /* Not Reached      */
                 (!NA        = SYSMIS ) /* Not Administered */
                 (!OM        = 0      ) /* Omitted          */
                 (!OTHER     = 0      ) /* Other Missing    */
                 (ELSE       = 0      ).
    !DOEND .
 !IFEND .

!ENDDEFINE.

DEFINE DOIT (COUNTRY = !CHAREND('/') ) .

* Specify the path for the SPSS data files following the format x:\xxx\ .
* <path> must be edited .

!LET !LIBDAT = !UNQUOTE("<path>") .

* Country loop .

!DO !CTY !IN (!COUNTRY) .

* Get the student achievement data .

ADD FILES
  / FILE = !QUOTE(!CONCAT(!LIBDAT,'MSA',!CTY,'M1.SAV')) .

* Score multiple-choice items with A key .

SCOREIT  Type  = MC      /
         Item  = MA13002  MA13007  MA13011  MA13021  MA13065  MA13068  MA13084
                 MA13090  MA13093  /
         RIGHT = 1       /
         NR    = 6       /
         NA    = sysmis  /
         OM    = 9       /
         OTHER = 7       .

* Score multiple-choice items with B key .

SCOREIT  Type  = MC      /
         Item  = MA13004  MA13018  MA13019  MA13024  MA13067  MA13070  MA13082
                 MA13086  MA13087  /
         RIGHT = 2       /
         NR    = 6       /
         NA    = sysmis  /
         OM    = 9       /
         OTHER = 7       .

* Score multiple-choice items with C key .

SCOREIT  Type  = MC      /
         Item  = MA13009  MA13012  MA13015  MA13020  MA13066  MA13073  MA13085
                 MA13088  /
         RIGHT = 3       /
         NR    = 6       /
         NA    = sysmis  /
         OM    = 9       /
         OTHER = 7       .

* Score multiple-choice items with D key .

SCOREIT  Type  = MC       /
         Item  = MA13001  MA13006  MA13008  MA13016  MA13069  MA13074  MA13083  /
         RIGHT = 4       /
         NR    = 6       /
         NA    = sysmis  /
         OM    = 9       /
         OTHER = 7       .

* Score multiple-choice items with E key .

SCOREIT  Type  = MC       /
         Item  = MA13003  MA13013  MA13017  MA13064  MA13089  /
         RIGHT = 5       /
         NR    = 6       /
         NA    = sysmis  /
         OM    = 9       /
         OTHER = 7       .

* Score Constructed-Response Items .

SCOREIT  Type  = CR      /
         Item  = MA13025A MA13025B MA13026A MA13026B MA13027  MA13028  MA13029
                 MA13075  MA13076  MA13077  MA13078  MA13079  MA13080  MA13081
                 MA13094  MA13095  MA13097  MA13098  MA13099  /
         RIGHT =  0      /
         NR    = 96      /
         NA    = sysmis  /
         OM    = 99      /
         OTHER = 90      .

EXECUTE.

* Save the student data .

SAVE OUTFILE = !QUOTE(!CONCAT(!LIBDAT,'MSC',!CTY,'M1.SAV')) .

!DOEND .

!ENDDEFINE .

* Specify the list of countries to be processed .

DOIT COUNTRY = AUS AUT CAN CYP CZE FRA DEU DNK GRC ISR
               ITA LTU RUS SVN SWE CHE USA .
